"use strict";

var _tape = _interopRequireDefault(require("tape"));

var _reduxBundler = require("redux-bundler");

var _getOrgEventSourceBundle = _interopRequireDefault(require("./get-org-event-source-bundle"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const CREATED = 'ORG_EVENT_SOURCE_CREATED';

const getStore = (stubs, bundles) => (0, _reduxBundler.composeBundlesRaw)((0, _getOrgEventSourceBundle.default)({
  apiUrl: 'https://dev.api.xchart.com',
  orgIdSelector: 'selectSessionOrgIds'
}), _reduxBundler.appTimeBundle, _objectSpread({
  name: 'stubs',
  reducer: (state = 'full', {
    type,
    payload
  }) => {
    if (type === 'AUTH_STATE_SET') {
      return payload;
    }

    return state;
  },
  doUpdateAuthState: newState => ({
    type: 'AUTH_STATE_SET',
    payload: newState
  }),
  selectAuthStatus: state => state.stubs
}, stubs), ...(bundles ? bundles : []))();

(0, _tape.default)('getOrgEventSourceBundle subscribes/unsubscribes based on authState', t => {
  const store = getStore({
    selectSessionOrgIds: () => ['cfd', 'other'],
    doCreateOrgEventSource: orgId => ({
      dispatch
    }) => {
      dispatch({
        type: CREATED,
        payload: {
          id: orgId,
          eventSource: {
            orgId,
            close: () => {}
          }
        }
      });
    }
  });
  t.deepEqual(store.reactShouldCreateDeleteOrgEventSource(), {
    actionCreator: 'doCreateOrgEventSource',
    args: ['cfd']
  });
  store.doCreateOrgEventSource('cfd');
  t.deepEqual(store.reactShouldCreateDeleteOrgEventSource(), {
    actionCreator: 'doCreateOrgEventSource',
    args: ['other']
  });
  store.doCreateOrgEventSource('other');
  t.deepEqual(store.reactShouldCreateDeleteOrgEventSource(), undefined);
  store.doUpdateAuthState('none');
  t.deepEqual(store.selectAuthStatus(), 'none', 'auth status should now be "none"');
  t.deepEqual(store.reactShouldCreateDeleteOrgEventSource(), {
    actionCreator: 'doRemoveOrgEventSource',
    args: ['cfd']
  });
  store.doRemoveOrgEventSource('cfd');
  t.deepEqual(store.reactShouldCreateDeleteOrgEventSource(), {
    actionCreator: 'doRemoveOrgEventSource',
    args: ['other']
  });
  store.doRemoveOrgEventSource('other');
  t.deepEqual(store.reactShouldCreateDeleteOrgEventSource(), undefined);
  t.end();
});
(0, _tape.default)('getOrgEventSourceBundle subscribes/unsubscribes based on orgs', t => {
  const closeCalledOn = [];
  const store = getStore({
    selectAuthStatus: () => 'full',
    doCreateOrgEventSource: orgId => ({
      dispatch
    }) => {
      dispatch({
        type: CREATED,
        payload: {
          id: orgId,
          eventSource: {
            orgId,
            close: () => {
              closeCalledOn.push(orgId);
            }
          }
        }
      });
    }
  }, [{
    name: 'sessionOrgs',
    reducer: (state = ['cfd', 'other'], {
      type,
      payload
    }) => {
      if (type === 'UPDATE_SESSION_ORGS') {
        return payload;
      }

      return state;
    },
    doUpdateSessionOrgs: newState => ({
      type: 'UPDATE_SESSION_ORGS',
      payload: newState
    }),
    selectSessionOrgIds: state => state.sessionOrgs
  }]);
  store.doCreateOrgEventSource('cfd');
  store.doCreateOrgEventSource('other');
  t.deepEqual(store.reactShouldCreateDeleteOrgEventSource(), undefined);
  store.doUpdateSessionOrgs(['cfd']);
  t.deepEqual(store.reactShouldCreateDeleteOrgEventSource(), {
    actionCreator: 'doRemoveOrgEventSource',
    args: ['other']
  });
  store.doRemoveOrgEventSource('other');
  t.deepEqual(closeCalledOn, ['other'], 'should have called close');
  t.deepEqual(store.reactShouldCreateDeleteOrgEventSource(), undefined);
  t.end();
});