"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fetchDrugAutocomplete = exports.getDrugName = void 0;

var _moneyClip = require("money-clip");

const {
  set,
  get,
  getAll
} = (0, _moneyClip.getConfiguredCache)({
  maxAge: Infinity,
  version: 1,
  name: 'drug-name-cache'
});
const drugData = {};
getAll().then(dbValues => {
  Object.assign(drugData, dbValues);
});

const fetchDrug = id => fetch("https://rxnav.nlm.nih.gov/REST/rxcui/".concat(id, ".json")).then(res => res.json()).then(drugData => drugData.idGroup.name);

const getDrugName = id => {
  let found = drugData[id];

  if (found) {
    return Promise.resolve(found);
  }

  return get(id).then(res => {
    if (res) {
      drugData[id] = res;
      return res;
    }

    return fetchDrug(id).then(res => {
      if (res) {
        drugData[id] = res;
        set(id, res);
        return res;
      }
    });
  });
};

exports.getDrugName = getDrugName;

const fetchDrugAutocomplete = term => fetch("https://rxnav.nlm.nih.gov/REST/approximateTerm.json?maxEntries=4&term=".concat(encodeURIComponent(term))).then(res => res.json()).then(parsed => {
  const resultsById = (parsed.approximateGroup.candidate || []).reduce((result, item) => {
    const id = item.rxcui;

    if (!result[id]) {
      result[id] = {
        id,
        score: item.score
      };
    }

    return result;
  }, {});
  return Object.keys(resultsById);
}).then(ids => Promise.all(ids.map(getDrugName)).then(names => names.map((name, index) => ({
  id: ids[index],
  name
}))).then(matches => matches.filter(item => !!item.name)));

exports.fetchDrugAutocomplete = fetchDrugAutocomplete;